package OpenERP::XMLRPC::Simple;


our $VERSION = '0.24';


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

OpenERP::XMLRPC::Simple

=head1 VERSION

version 0.24

=head1 NAME

OpenERP::XMLRPC::Simple - XMLRPC Client tweaked for OpenERP interaction.

=head1 NOTHING TO SEE HERE

This is just a dummy module to aid dependency management

=head1 AUTHORS

=over 4

=item *

Benjamin Martin <ben@madeofpaper.co.uk>

=item *

Colin Newell <colin@opusvl.com>

=item *

Jon Allen (JJ) <jj@opusvl.com>

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by Colin Newell.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
